#!/bin/bash
#
# This script will find eosd processes which have hung
# while umounting (caused by upstream xroot issue:
# https://github.com/xrootd/xrootd/issues/418).
#
# Author: Dan van der Ster
# Date: 26 Sept 2016
#

export PATH=/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin:/sbin

# make sure we have lsof
which lsof &>/dev/null || exit

# 1) Find running eosd processes
PIDS=`pidof eosd`

# Kill the processes that don't have /dev/fuse open
for PID in $PIDS
do
	if ! lsof -b -n -p $PID 2>/dev/null | grep -q /dev/fuse
	then
		# kill PID if it is still eos[x]d. This is racey.
		CMDLINE=`cat /proc/${PID}/cmdline`
		logger -t eos-cleanup.sh "Killing eosd process ${PID} which doesn't have /dev/fuse open. CMDLINE=${CMDLINE}"
		grep -qs eosd /proc/${PID}/cmdline && kill -9 $PID 2>/dev/null
	fi
done

# 2) Find running eosxd processes
PIDS=`pidof eosxd`

# Kill the processes that don't have /dev/fuse open
for PID in $PIDS
do
	if ! lsof -b -n -p $PID 2>/dev/null | grep -q /dev/fuse
	then
		# kill PID if it is still eos[x]d. This is racey.
		CMDLINE=`cat /proc/${PID}/cmdline`
		logger -t eos-cleanup.sh "eosxd process ${PID} which doesn't have /dev/fuse open. CMDLINE=${CMDLINE}"
		#grep -qs eosxd /proc/${PID}/cmdline && kill -9 $PID 2>/dev/null
	fi
done

# 3) Find mounts in /eos/* which do not have a corresponding eosd or eosxd
# ONLY IF AUTOFS!!
if [ -f /etc/auto.eos ]
then
	# eosd mounts have type eos and are mounted in /eos/
	EOSD_MOUNTS=$(egrep '^eos' /proc/mounts | awk '{print $2}' | egrep '^/eos/')

	for MOUNT in $EOSD_MOUNTS
	do
		EOSD=$(pgrep -u root -f "eosd ${MOUNT}")
		if [ "${EOSD}" == "" ]
		then
			logger -t eos-cleanup.sh "${MOUNT} is mounted but corresponding eosd is not running. Unmounting."
			umount -l $MOUNT
		fi
	done

	# eosxd mounts have type fuse and are mounted in /eos/*
	EOSXD_MOUNTS=$(egrep '\bfuse\b' /proc/mounts | egrep -v '^eos' | awk '{print $2}' | egrep '^/eos/')
	for MOUNT in $EOSXD_MOUNTS
	do
		EOSXD=$(pgrep -u root -f "eosxd ${MOUNT}")
		if [ "${EOSXD}" == "" ]
		then
			logger -t eos-cleanup.sh "${MOUNT} is mounted but corresponding eosxd is not running. Unmounting."
			umount -l $MOUNT
		fi
	done
fi
