class eosclient::autofs () inherits eosclient {

  if $::eosclient::manage_autofs_rpm {
    ensure_packages('autofs')
  }

  $eosmounts = $::eosclient::mounts

  # get the list of EOS instances ready for eosxd FUSE mounting
  $eosclient_eosxd_ready_instances = $::eosclient::eosxd_ready
  $eosmounts_legacy = difference($eosmounts, $eosclient_eosxd_ready_instances)
  $eosmounts_eosxd  = intersection($eosmounts, $eosclient_eosxd_ready_instances)

  $_autofs_notify = $::eosclient::manage_autofs_service ? {
    true    => 'Service[autofs]',
    default => undef ,
  }

  # orderly removal of sysvinit versions of eos-fuse
  ensure_packages('eos-fuse', {'ensure' => 'absent'})
  ensure_packages('eos-fuse-sysv', {'ensure' => 'absent'})

  ini_setting { 'set autofs browse mode yes':
    ensure  => present,
    path    => '/etc/autofs.conf',
    section => ' autofs ',
    setting => 'browse_mode',
    value   => 'yes',
    notify  => $_autofs_notify,
    require =>  Package['autofs', 'eos-fuse', 'eos-fuse-sysv'],
  }
  -> file{'/etc/auto.eos': # add line for each instance to auto.eos: <instance> -fstype=eos :user
    content => template('eosclient/auto.eos.erb'),
    mode    => '0644',
    owner   => root,
    group   => root,
    notify  => $_autofs_notify,
  }
  -> augeas{'eos_automaster': # add line to auto.master: /eos /etc/auto.eos
    context => '/files/etc/auto.master/',
    lens    => 'Automaster.lns',
    incl    => '/etc/auto.master',
    changes => [
      'set 01      /eos',
      'set 01/map  /etc/auto.eos',
    ],
    onlyif  => 'match *[map="/etc/auto.eos"] size == 0',
    notify  => $_autofs_notify,
  }
  if $::eosclient::manage_autofs_service {
    ensure_resource('service','autofs',
      { ensure     => true,
        enable     => true,
        hasrestart => true,
      }
    )
  }
}
