class eosclient (
  Hash $instance_config,
  Hash $common_config,
  Array $eosxd_ready,
  String $version                = 'present',
  Boolean $enable_fuse           = false,
  Boolean $enable_pam_hook       = false,
  Boolean $enable_autofs         = false,
  Array[String] $mounts          = hiera_array('eos_mounts', []),
  Integer $yum_priority          = 9,
  Boolean $manage_autofs_service = true,
  Boolean $manage_autofs_rpm     = true,
  Integer $fuse_logrotate_days   = 7,
  Boolean $allow_osrepos         = true,
  Boolean $enable_lemon          = true,
) {

  # Deprecations.
  if hiera('eosclient_common_config',false) {
    fail('hiera eosclient_common_config should not be defined anywhere, confused')
  }
  if hiera('eosclient_eosxd_ready_instances',false) {
    fail('hiera eosclient_eosxd_ready_instances should not be defined anywhere, confused')
  }
  if hiera('eos_mounts',false) {
    deprecation('eos_mounts','The hiera key eos_mounts is deprecated, use eosclient::mounts instead..')
  }
  $_deprecated_eosclient_instance_config = lookup('eosclient_instance_config',Hash,'deep',{})
  unless empty($_deprecated_eosclient_instance_config) {
    deprecation('eosclient_instance_config','The hiera key eosclient_instance_config is deprecated, use eosclient::instance_config instead..')
  }
  $_deprecated_eosclient_custom_config   = lookup('eosclient_custom_config',Hash,'deep',{})
  unless empty($_deprecated_eosclient_custom_config) {
    deprecation('eosclient_custom_config','The hiera key eosclient_custom_config is deprecated, use eosclient::instance_config instead..')
  }

  if versioncmp($::operatingsystemmajrelease, '6') < 0 or $::architecture != 'x86_64' {
    fail ('eosclient supports only x86_64 and el6 or newer')
  }

  ensure_packages(['jemalloc', 'lsof'])

  if $allow_osrepos {
    osrepos::kojitag { 'eos':
      available_major_versions => [6, 7],
      description              => 'EOS binaries from CERN Koji',
      priority                 => $yum_priority,
      before                   => [Package['eos-client'], Package['eos-debuginfo']],
      enable_debuginfo         => 1,
    }
  }

  ensure_packages (['eos-client', 'eos-debuginfo'], {'ensure' => $version})

  if $enable_fuse {
    include ::eosclient::fuse
  }

  if $enable_pam_hook {
    include ::eosclient::fuse::interactive
  }
}
