require 'spec_helper'
describe 'eosclient' do

  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts
      end
      context 'enable_lemon false and no mounts' do
        let(:params){{ enable_lemon: false,
        }}
        it { is_expected.to compile.with_all_deps }
        it { is_expected.to have_eosclient__mount_resource_count(0) }
      end
      context 'enable_lemon false and some mounts' do
        it { is_expected.to compile.with_all_deps }
        let(:params){{ enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { should contain_class('eosclient') }
        it { should contain_package('eos-client').with_ensure('present') }
        it { is_expected.to have_lemon__metric_resource_count(0) }

      end
      context 'enable_lemon false and with version parameter set' do
        let(:params){{ version: '1.2.3',
                       enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_package('eos-client').with_ensure('1.2.3') }
      end
      context 'enable_lemon false and with enable_fuse parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_package('eos-fuse') }
        it { is_expected.not_to contain_service('autofs') }
      end
      context 'enable_lemon false,  and with enable_fuse parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_package('eos-fuse') }
        it { is_expected.not_to contain_service('autofs') }
      end
      context 'enable_lemon false, enable_autofs,  and with enable_fuse parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       enable_autofs: true,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_package('eos-fuse') }
        it { is_expected.to contain_service('autofs') }
      end
      context 'enable_lemon false, enable_autofs, manage_autofs_service=>false  and with enable_fuse parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       enable_autofs: true,
                       manage_autofs_service: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_package('eos-fuse') }
        it { is_expected.not_to contain_service('autofs') }
      end
      context 'enable_lemon false and with enable_pam_hook parameter set' do
        let(:params){{ enable_pam_hook: true,
                       enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_file('/etc/profile.d/eos-select.sh') }
      end
      context 'enable_lemon false, fuse true and with mounts parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       mounts: ['atlas','cms','home-a'],
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_file('/etc/sysconfig/eos.atlas') }
      end
      context 'enable_lemon false, fuse true, common_config, fuse and eosxd with mounts parameter set' do
        let(:params){{ enable_fuse: true,
                       enable_lemon: false,
                       eosxd_ready: ['home-a'],
                       mounts: ['atlas','cms','home-a'],
                       common_config: {'A' => 'B',
                                       'conf' => {'a' => 'b'},
                                      },
                       instance_config: { 'home-a' => { 'conf' => {'cache' => {'size-mb' => '1234' }}},
                                          'atlas'   => { 'C' => 'D' },
                                          'cms'     => { 'E' => 'F' },
                       }
        }}
        it { is_expected.to compile.with_all_deps }
        it { should contain_file('/etc/sysconfig/eos.atlas') }
        it { should contain_eosclient__mount('atlas') }
        it { should contain_eosclient__mount('home-a') }
        it { should_not contain_eosclient__conf__eosxd('atlas') }
        it { should contain_eosclient__conf__eosxd('home-a') }
        it { should contain_file('/etc/sysconfig/eos').with_content(%r{^export\sA=B$}) }
        it { should contain_file('/etc/sysconfig/eos').without_content(%r{^conf}) }
        it { should contain_file('/etc/sysconfig/eos.home-a').with_ensure('absent') }
        it { should contain_file('/etc/eos/fuse.atlas.conf').with_ensure('absent') }
        it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"size-mb":"1234"}) }
        it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"a":"b"}) }
        it { should contain_file('/etc/sysconfig/eos.atlas').with_content(%r{^export\s+A=B$}) }
        it { should contain_file('/etc/sysconfig/eos.cms').with_content(%r{^export\s+A=B$}) }
        it { should contain_file('/etc/sysconfig/eos.atlas').with_content(%r{^export\s+C=D$}) }
        it { should_not contain_file('/etc/sysconfig/eos.cms').with_content(%r{^export\s+C=D$}) }
        it { should contain_file('/etc/eos/fuse.home-a.conf').without_content(%r{"A"}) }
        it { should contain_file('/etc/sysconfig/eos.atlas').without_content(%r{size-mb}) }
        context 'with deprecated hiera variables' do
          let(:hiera_config) { 'spec/hiera.yaml' }
          it { should contain_file('/etc/sysconfig/eos.atlas') }
          it { should contain_eosclient__mount('atlas') }
          it { should contain_eosclient__mount('home-a') }
          it { should_not contain_eosclient__conf__eosxd('atlas') }
          it { should contain_eosclient__conf__eosxd('home-a') }
          it { should contain_file('/etc/sysconfig/eos').with_content(%r{^export\sA=B$}) }
          it { should contain_file('/etc/sysconfig/eos').without_content(%r{^conf}) }
          it { should contain_file('/etc/sysconfig/eos.home-a').with_ensure('absent') }
          it { should contain_file('/etc/eos/fuse.atlas.conf').with_ensure('absent') }
          it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"size-mb":"1234"}) }
          it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"a":"b"}) }
          it { should contain_file('/etc/sysconfig/eos.atlas').with_content(%r{^export\s+A=B$}) }
          it { should contain_file('/etc/sysconfig/eos.cms').with_content(%r{^export\s+A=B$}) }
          it { should contain_file('/etc/sysconfig/eos.atlas').with_content(%r{^export\s+C=D$}) }
          it { should_not contain_file('/etc/sysconfig/eos.cms').with_content(%r{^export\s+C=D$}) }
          it { should contain_file('/etc/eos/fuse.home-a.conf').without_content(%r{"A"}) }
          it { should contain_file('/etc/sysconfig/eos.atlas').without_content(%r{size-mb}) }
          it { should contain_file('/etc/sysconfig/eos.cms').with_content(%r{^export\sALPHA=BETA}) }
          it { should contain_file('/etc/sysconfig/eos.cms').without_content(%r{^conf}) }
          it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"eta":"theta"}) }
          it { should contain_file('/etc/sysconfig/eos').with_content(%r{^export\sIOTA=KAPPA$}) }
          it { should contain_file('/etc/eos/fuse.home-a.conf').with_content(%r{"lamda":"mu"}) }
        end
      end
    end
  end
end
